@@ -19,10 +19,10 @@ from loguru import logger
 from rich.console import Console
 
 from pyhdtoolkit.cpymadtools import lhc, matching, orbit, twiss
-from pyhdtoolkit.utils._misc import fullpath
 from pyhdtoolkit.utils.contexts import timeit
 from pyrws.constants import VARIED_IR_QUADRUPOLES
 from pyrws.utils import (
+    fullpath,
     get_independent_quadrupoles_powering_knobs,
     get_triplets_powering_knobs,
     get_tunes_and_chroma_knobs,
@@ -297,8 +297,8 @@ def get_matched_waist_shift_config(
         betx=nominal_twiss.BETX[MATCH_Q11_RIGHT],
         bety=nominal_twiss.BETY[MATCH_Q11_RIGHT],
     )
-    # TODO: maybe we add some constraints for the alpha at Q11 match points with a lower weight (let's say 0.5 to get half of the beta weight)
-    # this may help the matching a little bit
+    # Could add some constraints for the alpha at Q11 match points with a lower weight
+    # (let's say 0.5 to get half of the beta weight) to help the matching a little bit
 
     # We make a knob varying Q4 to Q10 included and we match
     lhc.vary_independent_ir_quadrupoles(madx, quad_numbers=VARIED_IR_QUADRUPOLES, sides=("R", "L"), ip=ip, beam=beam)
